@@ -45,6 +45,9 @@ struct up_session {
 	struct hlist_node node_by_up_seid;
 	struct hlist_node node_by_cp_seid;
 
+	/* item in up_endpoint->peers_by_up_seid: */
+	struct hlist_node ep_node_by_up_seid;
+
 	struct osmo_fsm_inst *fi;
 	/* backpointer */
 	struct up_peer *up_peer;
